function [fitresult, gof] = createFit(xdata, ydata,start_point,nbpeaks,constraints)
%CREATEFIT(VARNAME1,VARNAME2)
%  Create a fit.
%
%  Data for 'untitled fit 2' fit:
%      X Input : VarName1
%      Y Output: VarName2
%  Output:
%      fitresult : a fit object representing the fit.
%      gof : structure with goodness-of fit info.
%
%  See also FIT, CFIT, SFIT.

%  Auto-generated by MATLAB on 31-Mar-2015 14:40:41


%% Fit: 'untitled fit 2'.
[xData, yData] = prepareCurveData( xdata, ydata );

%Generate the fitting expression and variable list
PeaksExpression0 = 'a.*(exp(-((x-c)./(0.6.*b)) .^2).*(1-pr)+ pr./(1+((x-c)./(0.5.*b)).^2))';
VariableList0 = 'a b c p';
    FullExpression = '0';
    FullVariableList = {''};
    
startpointv = zeros(4*nbpeaks,1);
lowpointv = zeros(4*nbpeaks,1);
highpointv = zeros(4*nbpeaks,1);
lowpoint = start_point;
highpoint = start_point;

    for i = 1:nbpeaks
        t1 = strrep(PeaksExpression0,'a',['a' num2str(i)]);
        t2 = strrep(t1,'b',['b' num2str(i)]);
        t3 = strrep(t2,'c',['c' num2str(i)]);
        PeaksExpression(i,:) = strrep(t3,'pr',['pr' num2str(i)]);
        FullExpression = [FullExpression '+' PeaksExpression(i,:)];
        t = { ['c' char(num2str(i))],['b' char(num2str(i))],['a' char(num2str(i))],['pr' char(num2str(i))]};
        FullVariableList = [FullVariableList t];
        
        lowpoint.position(i) = start_point.position(i)-constraints.position(i); %peak position
        if start_point.width(i) > constraints.width(i)
            lowpoint.width(i) = start_point.width(i) - constraints.width(i); % peak width
        else
            lowpoint.width(i) = 0;
        end
        if start_point.amplitude(i) > constraints.amplitude(i)
            lowpoint.amplitude(i) = start_point.amplitude(i) - constraints.amplitude(i); % peak amplitude
        else
            lowpoint.amplitude(i) = 0;
        end
        if start_point.ratio(i) > constraints.ratio(i)
            lowpoint.ratio(i)= start_point.ratio(i) - constraints.ratio(i);  %  ratio of lorentzian
        else
            lowpoint.ratio(i)= 0;
        end

        
        highpoint.position(i) = start_point.position(i)+constraints.position(i); %peak position
        highpoint.width(i) = start_point.width(i) + constraints.width(i); % peak width
        highpoint.amplitude(i) = start_point.amplitude(i) + constraints.amplitude(i); % peak amplitude
        if start_point.ratio(i) + constraints.ratio(i)<1
            highpoint.ratio(i)= start_point.ratio(i) + constraints.ratio(i);  %  ratio of lorentzian
        else
            highpoint.ratio(i)= 1;
        end

        startpointv(4*(i-1)+1) = start_point.position(i);
        startpointv(4*(i-1)+2) = start_point.width(i);
        startpointv(4*(i-1)+3) = start_point.amplitude(i);
        startpointv(4*(i-1)+4) = start_point.ratio(i);

        lowpointv(4*(i-1)+1) = lowpoint.position(i);
        lowpointv(4*(i-1)+2) = lowpoint.width(i);
        lowpointv(4*(i-1)+3) = lowpoint.amplitude(i);
        lowpointv(4*(i-1)+4) = lowpoint.ratio(i);

        highpointv(4*(i-1)+1) = highpoint.position(i);
        highpointv(4*(i-1)+2) = highpoint.width(i);
        highpointv(4*(i-1)+3) = highpoint.amplitude(i);
        highpointv(4*(i-1)+4) = highpoint.ratio(i);
    end

FullVariableList = FullVariableList(2:length(FullVariableList));


ft = fittype(FullExpression,'dependent',{'y'},'independent',{'x'},'coefficients',FullVariableList);
% opts = fitoptions( 'Method', 'NonlinearLeastSquares' );
opts = fitoptions( 'Method', 'NonlinearLeastSquares' );
% opts.Display = 'Off';
% opts.Lower = [-Inf -Inf 0 -Inf -Inf 0 -Inf -Inf 0 -Inf -Inf 0];
opts.Lower = lowpointv;
opts.Upper = highpointv;


opts.StartPoint = startpointv;

% Fit model to data.
[fitresult, gof,output] = fit( xData, yData, ft, opts );
% Ci = confint(fitresult,0.67)


% Create a figure for the plots.
% figure( 'Name', 'untitled fit 2' );
fit_val = coeffvalues(fitresult);
for i = 1:nbpeaks
        c(i) = fit_val(4*(i-1)+1);
        b(i) = fit_val(4*(i-1)+2) ;
        a(i) = fit_val(4*(i-1)+3) ;
        pr(i) = fit_val(4*(i-1)+4) ;
        snglfit(i,:) = a(i).*(exp(-((xData-c(i))./(0.6.*b(i))) .^2).*(1-pr(i))+ pr(i)./(1+((xData-c(i))./(0.5.*b(i))).^2));
end

% figure(2)
% subplot( 2, 1, 1 );
% h = plot( fitresult, xData, yData );
% hold on
% for i = 1:nbpeaks
% plot(xData, snglfit(i,:));
% end
% hold off
% legend( h, 'VarName2 vs. VarName1', 'untitled fit 2', 'Location', 'NorthEast' );
% % Label axes
% xlabel VarName1
% ylabel VarName2
% grid on
% 
% % Plot residuals.
% subplot( 2, 1, 2 );
% h = plot( fitresult, xData, yData, 'residuals' );
% legend( h, 'untitled fit 2 - residuals', 'Zero Line', 'Location', 'NorthEast' );
% % Label axes
% xlabel VarName1
% ylabel VarName2
% grid on


